@@ -1,4 +1,4 @@
-from controller import Emitter
+from controller import Emitter, Camera
 from flockai.PyCatascopia.probelib.ProcessProbe import ProcessProbe
 from flockai.models.drones.autopilot_controlled_drone import AutopilotControlledDrone
 from flockai.models.drones.keyboard_controller_drone import KeyboardControlledDrone
@@ -93,8 +93,9 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
             f_led.set(led_on)
             led_on = not led_on
 
-    def capture_image(self):
-        pass
+    def get_image_array(self):
+        camera: Camera = self.devices['camera']['device']
+        return camera.getImageArray()
 
     def run(self):
         # Wait a second before starting
@@ -136,7 +137,7 @@ class KeyboardMavic2DJI(KeyboardControlledDrone):
             # t.run()
 
             # Send messages
-            transmit_time = self.send_msg(StringGenerator.get_random_message(100), emitter_devices)
+            transmit_time = self.send_msg(self.get_image_array(), emitter_devices)
             # print("Transmit time:", transmit_time)
 
             # Receive messages
